==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_results/mp0035_001/MP0035_GetActivity_001_Result.java <==

package net.datastream.schemas.mp_results.mp0035_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.activity_001.Activity;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PURCHASEORDERLINEID_Type;
import net.datastream.schemas.mp_fields.REQUISITIONLINEID_Type;
import net.datastream.schemas.mp_fields.WORKORDEREXT;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/Activity_001}Activity"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDEREXT"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUISITIONLINEID" minOccurs="0"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERLINEID" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="can_create_req" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="is_matlist_has_allocatedqty" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="is_activity_has_checklist_items" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0035_GetActivity_001_Result")
public class MP0035_GetActivity_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0035_GetActivity_001_Result.ResultData resultData;
    @XmlAttribute(name = "multiorg")
    protected String multiorg;
    @XmlAttribute(name = "can_create_req")
    protected String can_Create_Req;
    @XmlAttribute(name = "is_matlist_has_allocatedqty")
    protected String is_Matlist_Has_Allocatedqty;
    @XmlAttribute(name = "is_activity_has_checklist_items")
    protected String is_Activity_Has_Checklist_Items;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP0035_GetActivity_001_Result.ResultData }
     *     
     */
    public MP0035_GetActivity_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0035_GetActivity_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0035_GetActivity_001_Result.ResultData value) {
        this.resultData = value;
    }

    /**
     * Gets the value of the multiorg property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMultiorg() {
        if (multiorg == null) {
            return "false";
        } else {
            return multiorg;
        }
    }

    /**
     * Sets the value of the multiorg property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMultiorg(String value) {
        this.multiorg = value;
    }

    /**
     * Gets the value of the can_Create_Req property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCan_Create_Req() {
        if (can_Create_Req == null) {
            return "false";
        } else {
            return can_Create_Req;
        }
    }

    /**
     * Sets the value of the can_Create_Req property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCan_Create_Req(String value) {
        this.can_Create_Req = value;
    }

    /**
     * Gets the value of the is_Matlist_Has_Allocatedqty property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Matlist_Has_Allocatedqty() {
        if (is_Matlist_Has_Allocatedqty == null) {
            return "false";
        } else {
            return is_Matlist_Has_Allocatedqty;
        }
    }

    /**
     * Sets the value of the is_Matlist_Has_Allocatedqty property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Matlist_Has_Allocatedqty(String value) {
        this.is_Matlist_Has_Allocatedqty = value;
    }

    /**
     * Gets the value of the is_Activity_Has_Checklist_Items property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Activity_Has_Checklist_Items() {
        if (is_Activity_Has_Checklist_Items == null) {
            return "false";
        } else {
            return is_Activity_Has_Checklist_Items;
        }
    }

    /**
     * Sets the value of the is_Activity_Has_Checklist_Items property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Activity_Has_Checklist_Items(String value) {
        this.is_Activity_Has_Checklist_Items = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Activity_001}Activity"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDEREXT"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUISITIONLINEID" minOccurs="0"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERLINEID" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "activity",
        "workorderext",
        "equipmentid",
        "requisitionlineid",
        "purchaseorderlineid"
    })
    public static class ResultData {

        @XmlElement(name = "Activity", namespace = "http://schemas.datastream.net/MP_entities/Activity_001", required = true)
        protected Activity activity;
        @XmlElement(name = "WORKORDEREXT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected WORKORDEREXT workorderext;
        @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
        protected EQUIPMENTID_Type equipmentid;
        @XmlElement(name = "REQUISITIONLINEID", namespace = "http://schemas.datastream.net/MP_fields")
        protected REQUISITIONLINEID_Type requisitionlineid;
        @XmlElement(name = "PURCHASEORDERLINEID", namespace = "http://schemas.datastream.net/MP_fields")
        protected PURCHASEORDERLINEID_Type purchaseorderlineid;

        /**
         * Gets the value of the activity property.
         * 
         * @return
         *     possible object is
         *     {@link Activity }
         *     
         */
        public Activity getActivity() {
            return activity;
        }

        /**
         * Sets the value of the activity property.
         * 
         * @param value
         *     allowed object is
         *     {@link Activity }
         *     
         */
        public void setActivity(Activity value) {
            this.activity = value;
        }

        /**
         * Gets the value of the workorderext property.
         * 
         * @return
         *     possible object is
         *     {@link WORKORDEREXT }
         *     
         */
        public WORKORDEREXT getWORKORDEREXT() {
            return workorderext;
        }

        /**
         * Sets the value of the workorderext property.
         * 
         * @param value
         *     allowed object is
         *     {@link WORKORDEREXT }
         *     
         */
        public void setWORKORDEREXT(WORKORDEREXT value) {
            this.workorderext = value;
        }

        /**
         * Gets the value of the equipmentid property.
         * 
         * @return
         *     possible object is
         *     {@link EQUIPMENTID_Type }
         *     
         */
        public EQUIPMENTID_Type getEQUIPMENTID() {
            return equipmentid;
        }

        /**
         * Sets the value of the equipmentid property.
         * 
         * @param value
         *     allowed object is
         *     {@link EQUIPMENTID_Type }
         *     
         */
        public void setEQUIPMENTID(EQUIPMENTID_Type value) {
            this.equipmentid = value;
        }

        /**
         * Gets the value of the requisitionlineid property.
         * 
         * @return
         *     possible object is
         *     {@link REQUISITIONLINEID_Type }
         *     
         */
        public REQUISITIONLINEID_Type getREQUISITIONLINEID() {
            return requisitionlineid;
        }

        /**
         * Sets the value of the requisitionlineid property.
         * 
         * @param value
         *     allowed object is
         *     {@link REQUISITIONLINEID_Type }
         *     
         */
        public void setREQUISITIONLINEID(REQUISITIONLINEID_Type value) {
            this.requisitionlineid = value;
        }

        /**
         * Gets the value of the purchaseorderlineid property.
         * 
         * @return
         *     possible object is
         *     {@link PURCHASEORDERLINEID_Type }
         *     
         */
        public PURCHASEORDERLINEID_Type getPURCHASEORDERLINEID() {
            return purchaseorderlineid;
        }

        /**
         * Sets the value of the purchaseorderlineid property.
         * 
         * @param value
         *     allowed object is
         *     {@link PURCHASEORDERLINEID_Type }
         *     
         */
        public void setPURCHASEORDERLINEID(PURCHASEORDERLINEID_Type value) {
            this.purchaseorderlineid = value;
        }

    }

}

==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_results/mp0035_001/MP0035_GetActivity_001_Result.java <==

package net.datastream.schemas.mp_results.mp0035_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.activity_001.Activity;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PURCHASEORDERLINEID_Type;
import net.datastream.schemas.mp_fields.REQUISITIONLINEID_Type;
import net.datastream.schemas.mp_fields.WORKORDEREXT;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/Activity_001}Activity"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDEREXT"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUISITIONLINEID" minOccurs="0"/>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERLINEID" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *       &lt;attribute name="multiorg" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="can_create_req" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="is_matlist_has_allocatedqty" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="is_activity_has_checklist_items" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP0035_GetActivity_001_Result")
public class MP0035_GetActivity_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP0035_GetActivity_001_Result.ResultData resultData;
    @XmlAttribute(name = "multiorg")
    protected String multiorg;
    @XmlAttribute(name = "can_create_req")
    protected String can_Create_Req;
    @XmlAttribute(name = "is_matlist_has_allocatedqty")
    protected String is_Matlist_Has_Allocatedqty;
    @XmlAttribute(name = "is_activity_has_checklist_items")
    protected String is_Activity_Has_Checklist_Items;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP0035_GetActivity_001_Result.ResultData }
     *     
     */
    public MP0035_GetActivity_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP0035_GetActivity_001_Result.ResultData }
     *     
     */
    public void setResultData(MP0035_GetActivity_001_Result.ResultData value) {
        this.resultData = value;
    }

    /**
     * Obtient la valeur de la propriété multiorg.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMultiorg() {
        if (multiorg == null) {
            return "false";
        } else {
            return multiorg;
        }
    }

    /**
     * Définit la valeur de la propriété multiorg.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMultiorg(String value) {
        this.multiorg = value;
    }

    /**
     * Obtient la valeur de la propriété can_Create_Req.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCan_Create_Req() {
        if (can_Create_Req == null) {
            return "false";
        } else {
            return can_Create_Req;
        }
    }

    /**
     * Définit la valeur de la propriété can_Create_Req.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCan_Create_Req(String value) {
        this.can_Create_Req = value;
    }

    /**
     * Obtient la valeur de la propriété is_Matlist_Has_Allocatedqty.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Matlist_Has_Allocatedqty() {
        if (is_Matlist_Has_Allocatedqty == null) {
            return "false";
        } else {
            return is_Matlist_Has_Allocatedqty;
        }
    }

    /**
     * Définit la valeur de la propriété is_Matlist_Has_Allocatedqty.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Matlist_Has_Allocatedqty(String value) {
        this.is_Matlist_Has_Allocatedqty = value;
    }

    /**
     * Obtient la valeur de la propriété is_Activity_Has_Checklist_Items.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Activity_Has_Checklist_Items() {
        if (is_Activity_Has_Checklist_Items == null) {
            return "false";
        } else {
            return is_Activity_Has_Checklist_Items;
        }
    }

    /**
     * Définit la valeur de la propriété is_Activity_Has_Checklist_Items.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Activity_Has_Checklist_Items(String value) {
        this.is_Activity_Has_Checklist_Items = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/Activity_001}Activity"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDEREXT"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUISITIONLINEID" minOccurs="0"/>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERLINEID" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "activity",
        "workorderext",
        "equipmentid",
        "requisitionlineid",
        "purchaseorderlineid"
    })
    public static class ResultData {

        @XmlElement(name = "Activity", namespace = "http://schemas.datastream.net/MP_entities/Activity_001", required = true)
        protected Activity activity;
        @XmlElement(name = "WORKORDEREXT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected WORKORDEREXT workorderext;
        @XmlElement(name = "EQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
        protected EQUIPMENTID_Type equipmentid;
        @XmlElement(name = "REQUISITIONLINEID", namespace = "http://schemas.datastream.net/MP_fields")
        protected REQUISITIONLINEID_Type requisitionlineid;
        @XmlElement(name = "PURCHASEORDERLINEID", namespace = "http://schemas.datastream.net/MP_fields")
        protected PURCHASEORDERLINEID_Type purchaseorderlineid;

        /**
         * Obtient la valeur de la propriété activity.
         * 
         * @return
         *     possible object is
         *     {@link Activity }
         *     
         */
        public Activity getActivity() {
            return activity;
        }

        /**
         * Définit la valeur de la propriété activity.
         * 
         * @param value
         *     allowed object is
         *     {@link Activity }
         *     
         */
        public void setActivity(Activity value) {
            this.activity = value;
        }

        /**
         * Obtient la valeur de la propriété workorderext.
         * 
         * @return
         *     possible object is
         *     {@link WORKORDEREXT }
         *     
         */
        public WORKORDEREXT getWORKORDEREXT() {
            return workorderext;
        }

        /**
         * Définit la valeur de la propriété workorderext.
         * 
         * @param value
         *     allowed object is
         *     {@link WORKORDEREXT }
         *     
         */
        public void setWORKORDEREXT(WORKORDEREXT value) {
            this.workorderext = value;
        }

        /**
         * Obtient la valeur de la propriété equipmentid.
         * 
         * @return
         *     possible object is
         *     {@link EQUIPMENTID_Type }
         *     
         */
        public EQUIPMENTID_Type getEQUIPMENTID() {
            return equipmentid;
        }

        /**
         * Définit la valeur de la propriété equipmentid.
         * 
         * @param value
         *     allowed object is
         *     {@link EQUIPMENTID_Type }
         *     
         */
        public void setEQUIPMENTID(EQUIPMENTID_Type value) {
            this.equipmentid = value;
        }

        /**
         * Obtient la valeur de la propriété requisitionlineid.
         * 
         * @return
         *     possible object is
         *     {@link REQUISITIONLINEID_Type }
         *     
         */
        public REQUISITIONLINEID_Type getREQUISITIONLINEID() {
            return requisitionlineid;
        }

        /**
         * Définit la valeur de la propriété requisitionlineid.
         * 
         * @param value
         *     allowed object is
         *     {@link REQUISITIONLINEID_Type }
         *     
         */
        public void setREQUISITIONLINEID(REQUISITIONLINEID_Type value) {
            this.requisitionlineid = value;
        }

        /**
         * Obtient la valeur de la propriété purchaseorderlineid.
         * 
         * @return
         *     possible object is
         *     {@link PURCHASEORDERLINEID_Type }
         *     
         */
        public PURCHASEORDERLINEID_Type getPURCHASEORDERLINEID() {
            return purchaseorderlineid;
        }

        /**
         * Définit la valeur de la propriété purchaseorderlineid.
         * 
         * @param value
         *     allowed object is
         *     {@link PURCHASEORDERLINEID_Type }
         *     
         */
        public void setPURCHASEORDERLINEID(PURCHASEORDERLINEID_Type value) {
            this.purchaseorderlineid = value;
        }

    }

}
